'' =================================================================================================
''
''   File....... jm_eeprom_demo.spin
''   Purpose.... 
''   Author..... Jon "JonnyMac" McPhalen
''               Copyright (c) 2013 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon@jonmcphalen.com
''   Started.... 
''   Updated.... 02 SEP 2013
''
'' =================================================================================================


con

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                          ' use 5MHz crystal

  CLK_FREQ = ((_clkmode - xtal1) >> 6) * _xinfreq               ' system freq as a constant
  MS_001   = CLK_FREQ / 1_000                                   ' ticks in 1ms
  US_001   = CLK_FREQ / 1_000_000                               ' ticks in 1us


con

  RX1 = 31                                                      ' programming / terminal
  TX1 = 30
  
  SDA = 29                                                      ' eeprom / i2c
  SCL = 28


con 

  #(-1), IS_ON, IS_OFF

  #0, LSBFIRST, MSBFIRST
  

con

   #1, HOME, GOTOXY, #8, BKSP, TAB, LF, CLREOL, CLRDN, CR       ' PST formmatting control
  #14, GOTOX, GOTOY, CLS


obj

  term : "fullduplexserial64"
  i2c  : "jm_i2c"
 

var


dat

  ' Address of following string determined to be $004C
  ' -- use F8 in Propeller Tool

  Msg                   byte    "JonnyMac's Propeller Programming Attack!", 0


pub main | p_str, c

  term.start(RX1, TX1, %0000, 115_200)                          ' start serial for terminal
  i2c.setup                                                     ' connect to EE buss
  pause(10)

  term.tx(CLS)
  term.str(string("EEPROM Read Demo", CR))
  term.str(string("-- $004C: "))

  p_str := $004C                                                ' starting address in EE
  
  repeat
    c := rd_byte(p_str++)
    if (c > 0)
      term.tx(c)
    else
      quit
 
  repeat
    waitcnt(0)


con

  { --------------- }
  {                 }
  {   E E P R O M   }
  {                 }
  { --------------- }


pub rd_byte(address) | value

  i2c.start
  i2c.write($A0)                                                ' boot EE slave ID, write
  i2c.write(address.byte[1])                                    ' write address (msb first)
  i2c.write(address.byte[0])
  i2c.start                                                     ' restart
  i2c.write($A1)                                                ' set to read
  value := i2c.read(i2c#NAK)                                    ' read one byte
  i2c.stop

  return value


pub rd_word(address) | value


pub rd_long(address) | value


pub wr_byte(value, address)


pub wr_word(value, address)


pub wr_long(value, address)


con

  { --------------- }
  {                 }
  {   B A S I C S   }
  {                 }
  { --------------- }


pub pause(ms) | t

'' Delay program in milliseconds

  if (ms < 1)                                                   ' delay must be > 0
    return
  else
    t := cnt - 1776                                             ' sync with system counter
    repeat ms                                                   ' run delay
      waitcnt(t += MS_001)
    

pub high(pin)

'' Makes pin output and high

  outa[pin] := 1
  dira[pin] := 1


pub low(pin)

'' Makes pin output and low

  outa[pin] := 0
  dira[pin] := 1


pub toggle(pin)

'' Toggles pin state

  !outa[pin]
  dira[pin] := 1


pub input(pin)

'' Makes pin input and returns current state

  dira[pin] := 0

  return ina[pin]
  

dat

{{

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}